@@ -710,20 +710,20 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
         impl #impl_generics checkout_server::Server<#common_lifetime, #context_type_name #ty_generics> for #server_type_name {
             type Context = checkout_server::ServerContext;
 
-            fn api_description() -> checkout_server::ApiDescription<()> {
+            fn api_description() -> checkout_server::ApiDescription<Self::Context> {
                 let mut api = checkout_server::ApiDescription::new();
                 api.register(checkout_server::create_endpoint).unwrap();
-                api.register(checkout_server::add_item_endpoint).unwrap();
-                api.register(checkout_server::remove_item_endpoint).unwrap();
-                api.register(checkout_server::confirm_items_endpoint).unwrap();
-                api.register(checkout_server::update_contact_endpoint).unwrap();
-                api.register(checkout_server::update_shipping_address_endpoint).unwrap();
-                api.register(checkout_server::update_fulfillment_type_endpoint).unwrap();
-                api.register(checkout_server::initiate_payment_endpoint).unwrap();
-                api.register(checkout_server::step_payment_endpoint).unwrap();
-                api.register(checkout_server::callback_payment_endpoint).unwrap();
-                api.register(checkout_server::cancel_payment_endpoint).unwrap();
-                api.register(checkout_server::initiate_order_endpoint).unwrap();
+                // api.register(checkout_server::add_item_endpoint).unwrap();
+                // api.register(checkout_server::remove_item_endpoint).unwrap();
+                // api.register(checkout_server::confirm_items_endpoint).unwrap();
+                // api.register(checkout_server::update_contact_endpoint).unwrap();
+                // api.register(checkout_server::update_shipping_address_endpoint).unwrap();
+                // api.register(checkout_server::update_fulfillment_type_endpoint).unwrap();
+                // api.register(checkout_server::initiate_payment_endpoint).unwrap();
+                // api.register(checkout_server::step_payment_endpoint).unwrap();
+                // api.register(checkout_server::callback_payment_endpoint).unwrap();
+                // api.register(checkout_server::cancel_payment_endpoint).unwrap();
+                // api.register(checkout_server::initiate_order_endpoint).unwrap();
 
                 api
             }
